.. Patent Client documentation master file, created by
   sphinx-quickstart on Wed Oct 24 10:48:07 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Patent Client's documentation!
=========================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   getting_started
   us_application
   assignments
   ptab
   epo
   developer/overview


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
